==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property outputSdt
 * @property repInterval
 * @property serviceName
 * @property serviceProviderName
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs(
    public val outputSdt: Output<String>? = null,
    public val repInterval: Output<Int>? = null,
    public val serviceName: Output<String>? = null,
    public val serviceProviderName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.builder()
            .outputSdt(outputSdt?.applyValue({ args0 -> args0 }))
            .repInterval(repInterval?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 }))
            .serviceProviderName(serviceProviderName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgsBuilder
internal constructor() {
    private var outputSdt: Output<String>? = null

    private var repInterval: Output<Int>? = null

    private var serviceName: Output<String>? = null

    private var serviceProviderName: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("tmhxjwcomquhybjg")
    public suspend fun outputSdt(`value`: Output<String>) {
        this.outputSdt = value
    }

    /**
     * @param value
     */
    @JvmName("jheilaeeoxmoeumd")
    public suspend fun repInterval(`value`: Output<Int>) {
        this.repInterval = value
    }

    /**
     * @param value
     */
    @JvmName("vsxcouueoalvqgja")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value
     */
    @JvmName("gcfhsyhdxbhuewas")
    public suspend fun serviceProviderName(`value`: Output<String>) {
        this.serviceProviderName = value
    }

    /**
     * @param value
     */
    @JvmName("eihgjgvxjljeprqw")
    public suspend fun outputSdt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outputSdt = mapped
    }

    /**
     * @param value
     */
    @JvmName("fobujqwvcvtmldbq")
    public suspend fun repInterval(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repInterval = mapped
    }

    /**
     * @param value
     */
    @JvmName("epbpnxmbujjltbny")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    /**
     * @param value
     */
    @JvmName("spavwuhrtpsirgvx")
    public suspend fun serviceProviderName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderName = mapped
    }

    internal fun build():
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs(
            outputSdt = outputSdt,
            repInterval = repInterval,
            serviceName = serviceName,
            serviceProviderName = serviceProviderName,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property outputSdt
 * @property repInterval
 * @property serviceName
 * @property serviceProviderName
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs(
    public val outputSdt: Output<String>? = null,
    public val repInterval: Output<Int>? = null,
    public val serviceName: Output<String>? = null,
    public val serviceProviderName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs.builder()
            .outputSdt(outputSdt?.applyValue({ args0 -> args0 }))
            .repInterval(repInterval?.applyValue({ args0 -> args0 }))
            .serviceName(serviceName?.applyValue({ args0 -> args0 }))
            .serviceProviderName(serviceProviderName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgsBuilder
internal constructor() {
    private var outputSdt: Output<String>? = null

    private var repInterval: Output<Int>? = null

    private var serviceName: Output<String>? = null

    private var serviceProviderName: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("qnfbtvlhhvvgitow")
    public suspend fun outputSdt(`value`: Output<String>) {
        this.outputSdt = value
    }

    /**
     * @param value
     */
    @JvmName("apwuflplrhtrebir")
    public suspend fun repInterval(`value`: Output<Int>) {
        this.repInterval = value
    }

    /**
     * @param value
     */
    @JvmName("coehbrjuhnidmkru")
    public suspend fun serviceName(`value`: Output<String>) {
        this.serviceName = value
    }

    /**
     * @param value
     */
    @JvmName("pvuywiedlyupbyry")
    public suspend fun serviceProviderName(`value`: Output<String>) {
        this.serviceProviderName = value
    }

    /**
     * @param value
     */
    @JvmName("xvkmhmptumkkwjdj")
    public suspend fun outputSdt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outputSdt = mapped
    }

    /**
     * @param value
     */
    @JvmName("qsywsrfbnrfnquhd")
    public suspend fun repInterval(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repInterval = mapped
    }

    /**
     * @param value
     */
    @JvmName("dgyygxhxcsxsbmke")
    public suspend fun serviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceName = mapped
    }

    /**
     * @param value
     */
    @JvmName("akinxvhamhibrvrx")
    public suspend fun serviceProviderName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceProviderName = mapped
    }

    internal fun build(): ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbSdtSettingsArgs(
            outputSdt = outputSdt,
            repInterval = repInterval,
            serviceName = serviceName,
            serviceProviderName = serviceProviderName,
        )
}
